﻿using System;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;

using System.Data;
using System.Configuration;
using System.Web.Security;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using Telerik.Web.UI;
using System.Collections.Generic;

public partial class Default : System.Web.UI.Page 
{
    protected void Page_Load(object sender, EventArgs e)
    {

    }

	private List<DockState> CurrentDockStates
	{
		get
		{
			//Store the info about the added docks in the session. For real life
			// applications we recommend using database or other storage medium
			// for persisting this information.
			List<DockState> _currentDockStates = (List<DockState>)Session["CurrentDockStatesDynamicDocks"];
			if (Object.Equals(_currentDockStates, null))
			{
				_currentDockStates = new List<DockState>();
				Session["CurrentDockStatesDynamicDocks"] = _currentDockStates;
			}
			return _currentDockStates;
		}
		set
		{
			Session["CurrentDockStatesDynamicDocks"] = value;
		}
	}

	private RadDock CreateRadDockFromState(DockState state)
	{
		RadDock dock = new RadDock();
		dock.DockMode = DockMode.Docked;
		dock.ID = string.Format("RadDock{0}", state.UniqueName);
		dock.ApplyState(state);

		Control WebUserControl = LoadControl("~/WebUserControl.ascx");
		dock.ContentContainer.Controls.Add(WebUserControl);

		dock.Commands.Add(new DockCloseCommand());
		dock.Commands.Add(new DockExpandCollapseCommand());

		return dock;
	}

	private RadDock CreateRadDock()
	{
		int docksCount = CurrentDockStates.Count;

		RadDock dock = new RadDock();
		dock.DockMode = DockMode.Docked;
		dock.UniqueName = Guid.NewGuid().ToString().Replace("-", "a");
		dock.ID = string.Format("RadDock{0}", dock.UniqueName);
		dock.Title = "Dock";
		dock.Text = string.Format("Added at {0}", DateTime.Now);
		dock.Width = Unit.Pixel(300);

		Control WebUserControl = LoadControl("~/WebUserControl.ascx");
		dock.ContentContainer.Controls.Add(WebUserControl);

		dock.Commands.Add(new DockCloseCommand());
		dock.Commands.Add(new DockExpandCollapseCommand());

		return dock;
	}

	private void CreateSaveStateTrigger(RadDock dock)
	{
		//Ensure that the RadDock control will initiate postback
		// when its position changes on the client or any of the commands is clicked.
		//Using the trigger we will "ajaxify" that postback.
		dock.AutoPostBack = true;
		dock.CommandsAutoPostBack = true;

		AsyncPostBackTrigger saveStateTrigger = new AsyncPostBackTrigger();
		saveStateTrigger.ControlID = dock.ID;
		saveStateTrigger.EventName = "DockPositionChanged";
		UpdatePanel1.Triggers.Add(saveStateTrigger);

		saveStateTrigger = new AsyncPostBackTrigger();
		saveStateTrigger.ControlID = dock.ID;
		saveStateTrigger.EventName = "Command";
		UpdatePanel1.Triggers.Add(saveStateTrigger);
	}

	protected void Page_Init(object sender, EventArgs e)
	{
		//Recreate the docks in order to ensure their proper operation
		for (int i = 0; i < CurrentDockStates.Count; i++)
		{
			RadDock dock = CreateRadDockFromState(CurrentDockStates[i]);
			//We will just add the RadDock control to the RadDockLayout.
			// You could use any other control for that purpose, just ensure
			// that it is inside the RadDockLayout control.
			// The RadDockLayout control will automatically move the RadDock
			// controls to their corresponding zone in the LoadDockLayout
			// event (see below).
			RadDockLayout1.Controls.Add(dock);
			//We want to save the dock state every time a dock is moved.
			CreateSaveStateTrigger(dock);
		}
	}

	protected void RadDockLayout1_LoadDockLayout(object sender, DockLayoutEventArgs e)
	{
		//Populate the event args with the state information. The RadDockLayout control
		// will automatically move the docks according that information.
		foreach (DockState state in CurrentDockStates)
		{
			e.Positions[state.UniqueName] = state.DockZoneID;
			e.Indices[state.UniqueName] = state.Index;
		}
	}

	protected void RadDockLayout1_SaveDockLayout(object sender, DockLayoutEventArgs e)
	{
		//Save the dock state in the page Session. This will enable us
		// to recreate the dock in the next Page_Init.
		CurrentDockStates = RadDockLayout1.GetRegisteredDocksState();
	}

	protected void ButtonAddDock_Click(object sender, EventArgs e)
	{
		RadDock dock = CreateRadDock();
		RadDockZone1.Controls.Add(dock);
		CreateSaveStateTrigger(dock);
	}
}
